@@ -14,6 +14,7 @@
 #include "lottie_private_common.hpp"
 #include "model/animation/join_animatables.hpp"
 #include "app_info.hpp"
+#include "io/utils.hpp"
 
 namespace glaxnimate::io::lottie::detail {
 
@@ -34,9 +35,10 @@ class LottieExporterState
     static constexpr const char* version = "5.7.1";
 
 public:
-    explicit LottieExporterState(ImportExport* format, model::Document* document, bool strip, bool strip_raster, const QVariantMap& settings )
+    explicit LottieExporterState(ImportExport* format, model::Composition* comp, bool strip, bool strip_raster, const QVariantMap& settings )
         : format(format),
-        document(document),
+        main(comp),
+        document(comp->document()),
         strip(strip),
         strip_raster( strip_raster ),
         auto_embed(settings["auto_embed"].toBool()),
@@ -45,7 +47,7 @@ public:
 
     QCborMap to_json()
     {
-        return convert_main(document->main());
+        return convert_main(main);
     }
 
     void convert_animation_container(model::AnimationContainer* animation, QCborMap& json)
@@ -64,14 +66,14 @@ public:
         json["layers"_l] = layers;
     }
 
-    QCborMap convert_main(model::MainComposition* animation)
+    QCborMap convert_main(model::Composition* animation)
     {
         layer_indices.clear();
         QCborMap json;
         json["v"_l] = version;
         convert_animation_container(animation->animation.get(), json);
         convert_object_basic(animation, json);
-        json["assets"_l] = convert_assets();
+        json["assets"_l] = convert_assets(animation);
         convert_composition(animation, json);
         if ( !strip )
             convert_meta(json);
@@ -125,6 +127,7 @@ public:
             QCborMap transform;
             convert_transform(grp->transform.get(), &grp->opacity, transform);
             json["ks"_l] = transform;
+            json["ao"_l] = int(grp->auto_orient.get());
 
             json["shapes"_l] = convert_shapes(grp->shapes, false);
         }
@@ -422,11 +425,13 @@ public:
         if ( prop->keyframe_count() > 1 )
         {
             jobj["a"_l] = 1;
+            std::vector<std::unique_ptr<model::KeyframeBase>> split_kfs = split_keyframes(prop);
+
             QCborArray keyframes;
             QCborMap jkf;
-            for ( int i = 0, e = prop->keyframe_count(); i < e; i++ )
+            for ( int i = 0, e = split_kfs.size(); i < e; i++ )
             {
-                auto kf = prop->keyframe(i);
+                auto kf = split_kfs[i].get();
                 QVariant v = transform_values.to_lottie(kf->value(), kf->time());
                 QCborValue kf_value = keyframe_value_from_variant(v);
 
@@ -552,6 +557,8 @@ public:
         {
             if ( qobject_cast<model::Layer*>(gr) )
                 format->information(io::lottie::LottieFormat::tr("Lottie only supports layers in the top level"));
+            else if ( gr->auto_orient.get() )
+                format->information(io::lottie::LottieFormat::tr("Lottie only supports auto-orient layers in the top level"));
             auto shapes = convert_shapes(gr->shapes, force_hidden || !gr->visible.get());
             QCborMap transform;
             transform["ty"_l] = "tr";
@@ -609,7 +616,7 @@ public:
         return jshapes;
     }
 
-    QCborArray convert_assets()
+    QCborArray convert_assets(model::Composition* animation)
     {
         QCborArray assets;
 
@@ -630,8 +637,11 @@ public:
             }
         }
 
-        for ( const auto& comp : document->assets()->precompositions->values )
-            assets.push_back(convert_precomp(comp.get()));
+        for ( const auto& comp : document->assets()->compositions->values )
+        {
+            if ( comp.get() != animation )
+                assets.push_back(convert_precomp(comp.get()));
+        }
 
         return assets;
     }
@@ -665,7 +675,7 @@ public:
         }
         else
         {
-            convert_animation_container(document->main()->animation.get(), json);
+            convert_animation_container(main->animation.get(), json);
         }
     }
 
@@ -701,7 +711,7 @@ public:
         return json;
     }
 
-    QCborMap convert_precomp(model::Precomposition* comp)
+    QCborMap convert_precomp(model::Composition* comp)
     {
         QCborMap out;
         convert_object_basic(comp, out);
@@ -729,6 +739,7 @@ public:
     }
 
     ImportExport* format;
+    model::Composition* main;
     model::Document* document;
     bool strip;
     QMap<QUuid, int> layer_indices;
